Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(671)

Unified Diff: lib/dom/scripts/generator.py

Issue 10800104: Convert DOM and HTML frog to dart2js. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 8 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « lib/dom/scripts/dartgenerator.py ('k') | lib/dom/scripts/go.sh » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: lib/dom/scripts/generator.py
===================================================================
--- lib/dom/scripts/generator.py (revision 9862)
+++ lib/dom/scripts/generator.py (working copy)
@@ -56,9 +56,9 @@
}
#
# Custom native specs for the Frog dom.
#
-_frog_dom_custom_native_specs = {
+_dart2js_dom_custom_native_specs = {
# Decorate the singleton Console object, if present (workers do not have a
# console).
'Console': "=(typeof console == 'undefined' ? {} : console)",
@@ -68,13 +68,13 @@
}
#
# Custom native bodies for frog implementations of dom operations that
# appear in dart:dom_deprecated and dart:html. This is used to
# work-around the lack of a 'rename' feature in the 'native' string -
# the correct name is available on the DartName extended
# attribute. See Issue 1814
#
-dom_frog_native_bodies = {
+dom_dart2js_native_bodies = {
# Some JavaScript processors, especially tools like yuicompress and
# JSCompiler, choke on 'this.continue'
'IDBCursor.continueFunction':
@@ -152,8 +152,8 @@
return None
def MakeNativeSpec(javascript_binding_name):
- if javascript_binding_name in _frog_dom_custom_native_specs:
- return _frog_dom_custom_native_specs[javascript_binding_name]
+ if javascript_binding_name in _dart2js_dom_custom_native_specs:
+ return _dart2js_dom_custom_native_specs[javascript_binding_name]
else:
# Make the class 'hidden' so it is dynamically patched at runtime. This
# is useful not only for browser compat, but to allow code that links
@@ -56,9 +56,9 @@
}
#
-# Custom native specs for the Frog dom.
+# Custom native specs for the dart2js dom.
#
@@ -68,13 +68,13 @@
}
#
-# Custom native bodies for frog implementations of dom operations that
+# Custom native bodies for dart2js implementations of dom operations that
# appear in dart:dom_deprecated and dart:html. This is used to
# work-around the lack of a 'rename' feature in the 'native' string -
« no previous file with comments | « lib/dom/scripts/dartgenerator.py ('k') | lib/dom/scripts/go.sh » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698